@@ -35,6 +35,7 @@ def runMain(moduleName=None, **parDict):
         isDebug = not not moduleName
         try:
             logFolder = b.getPath(workspacePath, "log")
+            b.makeFolder(logFolder)
             for logFile in sorted(b.getAllFileList(logFolder), reverse=True)[100:]:
                 b.remove(logFile)
             logFile = b.getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
@@ -94,3 +95,7 @@ def initParDict():
             parDict[parName] = parValue
         index += 1
     return moduleName, parDict
+
+
+def isDev():
+    return sys.executable.endswith("python.exe")
